/*
	Actiona
	Copyright (C) 2005 Jonathan Mercier-Ganady

	Actiona is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Actiona is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, see <http://www.gnu.org/licenses/>.

	Contact : jmgr@jmgr.info
*/

#pragma once

#include "actioninstance.h"

#include <QMediaPlayer>
#include <QMediaPlaylist>

namespace Actions
{
	class PlaySoundInstance : public ActionTools::ActionInstance
	{
		Q_OBJECT

	public:
		PlaySoundInstance(const ActionTools::ActionDefinition *definition, QObject *parent = nullptr);
		~PlaySoundInstance() override;

		void startExecution() override;
		void pauseExecution() override;
		void resumeExecution() override;
		void stopExecution() override;
		void stopLongTermExecution() override;

	private slots:
		void stateChanged(QMediaPlayer::State state);

	private:
		QMediaPlayer *mMediaPlayer;
		QMediaPlaylist *mMediaPlaylist;
		bool mBlocking;

		Q_DISABLE_COPY(PlaySoundInstance)
	};
}

